@@ -78,6 +78,7 @@ class ServerConnection(threading.Thread):
     def prepare_connection(self):
         if not self.is_running:
             raise ConnectionAbortedError("Lost connection to RabbitMQ Server")
+        LOGGER.info(f'Connection to {self.server} prepared')
         yield
         self._reconnect_channel()
 
@@ -85,7 +86,7 @@ class ServerConnection(threading.Thread):
         self._running = True
         while self._running:
             try:
-                self._connection.process_data_events(time_limit=1)
+                self._connection.process_data_events(time_limit=2)
             except (StreamLostError, AMQPConnectionError, ConnectionError) as e:
                 LOGGER.error(
                     f"Error in connection to {self.server}: {e}, closing connection"
@@ -112,6 +113,7 @@ class ServerConnection(threading.Thread):
             raise NotAuthenticatedError(
                 f"Not authenticated to connect to server {self.server}"
             )
+        LOGGER.info(f'Connection established to {self.server}')
 
     def _close(self) -> None:
         self._connection.process_data_events()
@@ -133,6 +135,7 @@ class ServerConnection(threading.Thread):
             self._confirmed_channel.confirm_delivery()
 
     def add_callback(self, callback: Callable, *args, **kwargs) -> None:
+        LOGGER.info(f'Adding callback on {self.server}: {callback}, args: {args}, kwargs: {kwargs}')
         self._connection.add_callback_threadsafe(lambda: callback(*args, **kwargs))
 
     def _reconnect_channel(self) -> None:
@@ -234,7 +237,9 @@ class ReconnectConnection(ServerConnection):
             super().add_callback(callback, *args, **kwargs)
 
     def wait_for_reconnect(self, timeout=None) -> bool:
+        LOGGER.info(f'Waiting for reconnect to {self.server}')
         self._reconnecting.wait(timeout=timeout)
+        LOGGER.info(f'Finished waiting for reconnect to {self.server}')
         return self.is_reconnecting
 
     def _reconnect_channel(self) -> None:
